@@ -7,6 +7,8 @@ import sys
 import time
 import argparse
 
+import conda
+from distutils.version import LooseVersion
 from conda_build.metadata import MetaData
 
 from . import ci_register
@@ -272,6 +274,12 @@ def main():
     else:
         args = parser.parse_args()
 
+    # Check conda version for compatibility
+    if LooseVersion(conda.__version__) >= LooseVersion('4.3'):
+        print('You appear to be using conda {}, but conda-smithy {} is\ncurrently only compatible with conda versions < 4.3.'.format(
+            conda.__version__, __version__))
+        sys.exit(2)
+
     args.subcommand_func(args)
 
 
